---
title: "Home"
mode: "wide"
---

import { PopularResources } from '/snippets/components/PopularResources.mdx';
import { ExploreContent } from '/snippets/components/ExploreContent.mdx';

<div class="homepage-hero-section">
  <div class="hero-content">
    <div class="hero-logo-section">
      <img class="hero-logo" noZoom src="/static/img/ag2.svg" alt="AG2 Logo" />
    </div>
    <div class="hero-text-section">
      <h2 class="hero-title">AG2</h2>
      <p class="hero-subtitle">The Open Source Agent OS</p>
      <a class="hero-btn" href="/docs/Getting-Started">
        <div>Getting Started - 3 Minute</div>
      </a>
    </div>
  </div>
</div>

### Key Features

<div class="key-features">
    <CardGroup cols={3}>
        <Card>
            <div class="key-feature">
                <img noZoom src="/static/img/conv_2.svg" alt="Multi-Agent Conversation Framework" />
                <a href="/docs/Use-Cases/agent_chat">
                    Multi-Agent Conversation Framework
                </a>
                <p>AG2 provides multi-agent conversation framework as a high-level abstraction. With this framework, one can conveniently build LLM workflows.</p>
            </div>
        </Card>
        <Card>
            <div class="key-feature">
                <img noZoom src='/static/img/autogen_app.svg' alt='Easily Build Diverse Applications' />
                <a href='/docs/Use-Cases/agent_chat#diverse-applications-implemented-with-autogen'>
                    Easily Build Diverse Applications
                </a>
                <p>AG2 offers a collection of working systems spanning a wide range of applications from various domains and complexities.</p>
            </div>
        </Card>
        <Card>
            <div class="key-feature">
                <img noZoom src='/static/img/extend.svg' alt='Enhanced LLM Inference & Optimization' />
                <a href='/docs/Use-Cases/enhanced_inference'>
                    Enhanced LLM Inference & Optimization
                </a>
                <p>AG2 supports enhanced LLM inference APIs, which can be used to improve inference performance and reduce cost.</p>
            </div>
        </Card>
    </CardGroup>
</div>

### Explore content
<ExploreContent />

### Popular resources
<PopularResources />
